#SL:23/06/2017. This R code reproduces all analyses reported in the manuscript Leroux et al. Stoichiometric distribution models: ecological stoichiometry at the landscape extent. See manuscript text and data files metadata for a full description of the data used.

#Clear all previous data
rm(list=ls())

#List of packages that are used
library(boot)
library(AICcmodavg)
library(lme4)
library(minqa)
library(arm)
library(Rcpp)
library(RcppEigen)
library(MuMIn)
library(caTools)
library(gdata)
library(gtools)
library(gplots)
library(gclus)
library(registry)
library(iterators)
library(foreach)
library(TSP)
library(seriation)
library(corrgram)
library(blme)
library(permute)
library(car)
library(usdm)
library(fmsb)
library(pscl)
library(biomod2)
library(prettyR)
library(reshape2)
library(lattice)
library(gstat)
library(sp)


#################################################################
#Start with code to fit StDMs for white birch foliar chemistry
#################################################################

#Import raw white birch foliar chemistry data. 
wB_data <- read.csv("wB_FoliarChemistry_June2.csv") 

#################################################################
#Fit models of wB %C, or %N, or % P as a function of 6 landscape covariates. 
#%C
wB_C <- glm(PercentC ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=wB_data)
summary(wB_C)
#make some diagnostic plots of your model to assess fit
par(mfrow=c(2,3))
par(mai=c(0.8,0.85,0.15,0.1))
plot(wB_C)
hist(resid(wB_C))

#%N
wB_N <- glm(PercentN ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=wB_data)
summary(wB_N)
#make some diagnostic plots of your model to assess fit
par(mfrow=c(2,3))
par(mai=c(0.8,0.85,0.15,0.1))
plot(wB_N)
hist(resid(wB_N))

#%P
wB_P <- glm(PercentP ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=wB_data)
summary(wB_P)
#make some diagnostic plots of your model to assess fit
par(mfrow=c(2,3))
par(mai=c(0.8,0.85,0.15,0.1))
plot(wB_P)
hist(resid(wB_P))

#################################################################
#k-fold cross validation for %C, %N, %P concentration models - TRUE models

cv.glm(data=wB_data, glmfit=wB_C, K=10)
cv.glm(data=wB_data, glmfit=wB_N, K=10)
cv.glm(data=wB_data, glmfit=wB_P, K=10)

#################################################################
#Cross-validation error is a relative measure therefore we need to generate random %C, %N, %P models so that we can compare cross validation of the "TRUE" model to the "random" models

#k-fold cross validation for %C, %N, %P concentration models - RANDOM models
#Random models are created by re-shuffling %C, %N, %P data, fitting models, then calculating cv.glm

##########
#%C models
#Put results of null Percent C LMs here
C_LM_Output <- NULL

#Do it 100 times
for(x in seq(1,100,1)){

#Step 1 - Re-shuffle the response
#Reshuffle stoich data and place in new file
CStoich_Shuf <- wB_data
#We are shuffling the seventh column as this is the Percent C column
CStoich_Shuf[,7] <-sample(CStoich_Shuf[,7])

#Step 2
#Run the model
#Need to do glm because boot works on glm. Normal distribution so same as lm.
wB_C_Rand <- glm(PercentC ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=CStoich_Shuf)

#Step 3
#Run cross validation
cv <-cv.glm(data=CStoich_Shuf, glmfit=wB_C_Rand, K=10)

#Step 4
#Collect the cv values for each model. For each iteration x save the cv.
C_LM_Output <- rbind(C_LM_Output, data.frame(Iteration = x, CV = cv$delta[2]))

print (x)
}

#Step 5
#Sort random set to calculate 90% CI for cv$delta[2]
C_LM_Output_Sort <- C_LM_Output[order(C_LM_Output$CV),]

##########
#%N models
#Put results of null Percent N LMs here
N_LM_Output <- NULL

#Do it 100 times
for(x in seq(1,100,1)){

#Step 1 - Re-shuffle the response
#Reshuffle stoich data and place in new file
NStoich_Shuf <- wB_data
#We are shuffling the fifth column as this is the Percent N column
NStoich_Shuf[,5] <-sample(NStoich_Shuf[,5])

#Step 2
#Run the model
#Need to do glm because boot package works on glm. 
wB_N_Rand <- glm(PercentN ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=NStoich_Shuf)

#Step 3
#Run cross validation
cv <-cv.glm(data=NStoich_Shuf, glmfit=wB_N_Rand, K=10)

#Step 4
#Collect the cv values for each model. For each iteration x save the cv.
N_LM_Output <- rbind(N_LM_Output, data.frame(Iteration = x, CV = cv$delta[2]))

print (x)
}

#Step 5
#Sort random set to calculate 90% CI for cv$delta[2]
N_LM_Output_Sort <- N_LM_Output[order(N_LM_Output$CV),]

#########
#%P models
#Put results of null Percent P LMs here
P_LM_Output <- NULL

#Do it 100 times
for(x in seq(1,100,1)){

#Step 1 - Re-shuffle the response
#Reshuffle stoich data and place in new file
PStoich_Shuf <- wB_data
#We are shuffling the sixth column as this is the Percent P column
PStoich_Shuf[,6] <-sample(PStoich_Shuf[,6])

#Step 2
#Run the model
#Need to do glm because boot works on glm. 
wB_P_Rand <- glm(PercentP ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=PStoich_Shuf)

#Step 3
#Run cross validation
cv <-cv.glm(data=PStoich_Shuf, glmfit=wB_P_Rand, K=10)

#Step 4
#Collect the cv values for each model. For each iteration x save the cv.
P_LM_Output <- rbind(P_LM_Output, data.frame(Iteration = x, CV = cv$delta[2]))

print (x)
}

#Step 5
#Sort random set to calculate 90% CI for cv$delta[2]
P_LM_Output_Sort <- P_LM_Output[order(P_LM_Output$CV),]

##################################################################################
#Format data for Qty models and fit wB Qty and wB ratio models
##################################################################################
#import transect data on height and basal diameter per small, medium, and large wB individuals per plot
#small
wB_sm <- read.csv("wB_Transect_small.csv")
#medium
wB_md <- read.csv("wB_Transect_medium.csv")
#large
wB_lg <- read.csv("wB_Transect_large.csv")

#Get mean height of small, medium, large wB
wBSm_H <-tapply(wB_sm$Height_cm, wB_sm$Plot_ID, mean)
wBMd_H <-tapply(wB_md$Height_cm, wB_md$Plot_ID, mean)
wBLg_H <-tapply(wB_lg$Height_cm, wB_lg$Plot_ID, mean)

#make table - mean height of small, medium, and large wB per plot.
wBSm_MeanH <- data.frame(PlotID=names(wBSm_H), value=wBSm_H)
wBMd_MeanH <- data.frame(PlotID=names(wBMd_H), value=wBMd_H)
wBLg_MeanH <- data.frame(PlotID=names(wBLg_H), value=wBLg_H)

#Get mean basal diameter of small, medium, large wB
wBSm_BD <-tapply(wB_sm$BasalDiameter_mm, wB_sm$Plot_ID, mean)
wBMd_BD <-tapply(wB_md$BasalDiameter_mm, wB_md$Plot_ID, mean)
wBLg_BD <-tapply(wB_lg$BasalDiameter_mm, wB_lg$Plot_ID, mean)

#make table
wBSm_MeanBD <- data.frame(PlotID=names(wBSm_BD), value=wBSm_BD)
wBMd_MeanBD <- data.frame(PlotID=names(wBMd_BD), value=wBMd_BD)
wBLg_MeanBD <- data.frame(PlotID=names(wBLg_BD), value=wBLg_BD)

##########################################################################
#Fit model to predict browsable wB foliar biomass as a function of height and basal diameter.
#Retain model with highest R^2

#import data
wB_Biomass <- read.csv("wB_BiomassData.csv")

################################################
#Run a few competing White birch biomass models
#DBH
wB_DBH <- lm(log(wB_Biomass$DryMass_g) ~ log(wB_Biomass$BasalDiameter_mm))
summary(wB_DBH)
#Height
wB_HEIGHT <- lm(log(wB_Biomass$DryMass_g) ~ log(wB_Biomass$Height_cm*10))
summary(wB_HEIGHT)
#DBH + Height
wB_DBH_HEIGHT <- lm(log(wB_Biomass$DryMass_g) ~ log(wB_Biomass$BasalDiameter_mm) + log(wB_Biomass$Height_cm*10))
summary(wB_DBH_HEIGHT)

#The top model for browsable wB foliage is Basal diameter + height

#################################################
#Fit biomass model to the above transect data to get mean biomass of a sm, md, and lg individual wB per plot
#Top model for wB was basal diameter + height. Equation: ln(biomass(g)) ~ -3.84 + 0.76*ln(basal diameter(mm)) + 0.68*ln(height(mm))
wBSm_MeanH$lnBiomass <- -3.84 + 0.76*log(wBSm_MeanBD$value) + 0.68*log(wBSm_MeanH$value*10)
wBMd_MeanH$lnBiomass <- -3.84 + 0.76*log(wBMd_MeanBD$value) + 0.68*log(wBMd_MeanH$value*10)
wBLg_MeanH$lnBiomass <- -3.84 + 0.76*log(wBLg_MeanBD$value) + 0.68*log(wBLg_MeanH$value*10)

#Get rid of ln - take exp of lnBiomass
wBSm_MeanH$Biomass <- exp(wBSm_MeanH$lnBiomass)
wBMd_MeanH$Biomass <- exp(wBMd_MeanH$lnBiomass)
wBLg_MeanH$Biomass <- exp(wBLg_MeanH$lnBiomass)

#Make NAs = 0 to avoid issues with merge later on
wBSm_MeanH[is.na(wBSm_MeanH)] <- 0
wBMd_MeanH[is.na(wBMd_MeanH)] <- 0
wBLg_MeanH[is.na(wBLg_MeanH)] <- 0

#################################################
#Get total biomass of sm, md, lg individuals per plot. 
#Multiply average small, medium, large biomass by # of individuals to get qty of sm, md, lg per plot
#Then sum across size classes to get plot-level biomass estimate.
#Import transect summary data
Density <- read.csv("wB_NumInd.csv")

#Merge data sets so we have same number of plots for analysis. Number will be dictated by presence or absence of wB in plot (TransectFull data)
QtyMerge_wBSm <- merge(wBSm_MeanH, Density, by.x = "PlotID", by.y = "PlotID")
QtyMerge_wBMd <- merge(wBMd_MeanH, Density, by.x = "PlotID", by.y = "PlotID")
QtyMerge_wBLg <- merge(wBLg_MeanH, Density, by.x = "PlotID", by.y = "PlotID")

#Multiply sm, md, lg wB biomass by # of individuals per plot
QtyMerge_wBSm$BiomassSm <- QtyMerge_wBSm$Biomass*QtyMerge_wBSm$Sm_PlotSquared_Ceiling
QtyMerge_wBMd$BiomassMd <- QtyMerge_wBMd$Biomass*QtyMerge_wBMd$Md_PlotSquared_Ceiling
QtyMerge_wBLg$BiomassLg <- QtyMerge_wBLg$Biomass*QtyMerge_wBLg$Lrg_PlotSquared_Ceiling

#Create data frame to calculate biomass sums. BiomassSum here is per plot. We will divide by plot area below to get g per m^2.
#Merge all data first with all.x and all.y = TRUE so all plot ids are included
BM_wB1 <- merge(QtyMerge_wBSm, QtyMerge_wBMd, by.x = "PlotID", by.y = "PlotID", all.x = TRUE, all.y = TRUE)
BM_wB2 <- merge(BM_wB1, QtyMerge_wBLg, by.x = "PlotID", by.y = "PlotID", all.x = TRUE, all.y = TRUE)
#Need to make NA = 0 for the sum
BM_wB2[is.na(BM_wB2)] <- 0
BiomassSum_wB <- data.frame(PlotID=BM_wB2$PlotID, BiomassSum=BM_wB2$BiomassSm + BM_wB2$BiomassMd +BM_wB2$BiomassLg)

## Remove 0 from the dataset to leave only plots with biomass data.
BiomassSum_wB_No0 <- BiomassSum_wB[apply(BiomassSum_wB[,-1],1, function(x) !any(x==0)),]

#####################################################################
#Make Qty of C, N, P per plot data files. Qty here is in g per m^2. 
#There are 10 plots with biomass data (i.e., where wB was found in transect) but where we do not have associated wB foliar chemistry. Merge biomass and chem files to remove 10 extra biomass plots. 
Qty_wB <- merge(BiomassSum_wB_No0, wB_data, by.x = "PlotID", by.y = "PlotID")
#Qty of C - add to Biomass file. BiomassSum is estimated at the plot level. Divide BiomassSum by 314.16 to get g per m^2. Divide element concentation by 100 to get proportion.
Qty_wB$Qty_C <- (Qty_wB$BiomassSum/314.16) * Qty_wB$PercentC/100
#Qty of N - add to Biomass file.  
Qty_wB$Qty_N <- (Qty_wB$BiomassSum/314.16) * Qty_wB$PercentN/100
#Qty of P - add to Biomass file
Qty_wB$Qty_P <- (Qty_wB$BiomassSum/314.16) * Qty_wB$PercentP/100

######################################################################
#Estimate molar mass to create C:N, C:P, and N:P molar ratios.
#To get molar mass divide mass by molar mass of N (14.0067), P (30.973762), C (12.0107) respectively.
Qty_wB$Molar_C <- Qty_wB$Qty_C/12.0107
Qty_wB$Molar_N <- Qty_wB$Qty_N/14.0067
Qty_wB$Molar_P <- Qty_wB$Qty_P/30.973762

#Add molar C:N, C:P, and N:P ratios to the Qty_wB data frame
Qty_wB$CNRatio <- Qty_wB$Molar_C / Qty_wB$Molar_N
Qty_wB$CPRatio <- Qty_wB$Molar_C / Qty_wB$Molar_P
Qty_wB$NPRatio <- Qty_wB$Molar_N / Qty_wB$Molar_P

#######################################################################
#Fit models of wB QtyC, or QtyN, or QtyP as a function of 6 landscape covariates.
#Log the response as it covers several orders of magnitude

#######################
#Fit models
#Qty C per plot
wB_Qty_Cmodel <- glm(log(Qty_C) ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=Qty_wB)
summary(wB_Qty_Cmodel)
#make some diagnostic plots of your model to assess fit
par(mfrow=c(2,3))
par(mai=c(0.8,0.85,0.15,0.1))
plot(wB_Qty_Cmodel)
hist(resid(wB_Qty_Cmodel))

#Qty N per plot
wB_Qty_Nmodel <- glm(log(Qty_N) ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=Qty_wB)
summary(wB_Qty_Nmodel)
#make some diagnostic plots of your model to assess fit
par(mfrow=c(2,3))
par(mai=c(0.8,0.85,0.15,0.1))
plot(wB_Qty_Nmodel)
hist(resid(wB_Qty_Nmodel))

#Qty P per plot
wB_Qty_Pmodel <- glm(log(Qty_P) ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=Qty_wB)
summary(wB_Qty_Pmodel)
#make some diagnostic plots of your model to assess fit
par(mfrow=c(2,3))
par(mai=c(0.8,0.85,0.15,0.1))
plot(wB_Qty_Pmodel)
hist(resid(wB_Qty_Pmodel))

###################################################
#k-fold cross validation for qty models - TRUE models

cv.glm(data=Qty_wB, glmfit=wB_Qty_Cmodel, K=10)
cv.glm(data=Qty_wB, glmfit=wB_Qty_Nmodel, K=10)
cv.glm(data=Qty_wB, glmfit=wB_Qty_Pmodel, K=10)

##################################################################
#Cross-validation error is a relative measure therefore we need to generate random QtyC, QtyN, QtyP models so that we can compare cross validation of the "TRUE" model to the "random" models
#k-fold cross validation for concentration models - random models
#Need to re-shuffle Qty data, fit models, calculate cv.glm

###############
#Qty C per plot
#Put results of null Qty C LMs here
QtyC_LM_Output <- NULL

#Do it 100 times
for(x in seq(1,100,1)){

#Step 1 - Re-shuffle the response
#Reshuffle stoich data and place in new file
QtyCStoich_Shuf <- Qty_wB
#We are shuffling the 14th column as this is the Qty C column
QtyCStoich_Shuf[,14] <-sample(QtyCStoich_Shuf[,14])

#Step 2
#Run the model
#Need to do glm because boot works on glm.
wB_QtyC_Rand <- glm(log(Qty_C) ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=QtyCStoich_Shuf)

#Step 3
#Run cross validation
cv <-cv.glm(data=QtyCStoich_Shuf, glmfit=wB_QtyC_Rand, K=10)

#Step 4
#Collect the cv values for each model. For each iteration x save the cv.
QtyC_LM_Output <- rbind(QtyC_LM_Output, data.frame(Iteration = x, CV = cv$delta[2]))

print (x)
}


#Step 5
#Sort random set to calculate 90% CI for cv$delta[2]
QtyC_LM_Output_Sort <- QtyC_LM_Output[order(QtyC_LM_Output$CV),]

################
#Qty N per plot
#Put results of null Total N LMs here
QtyN_LM_Output <- NULL

#Do it 100 times
for(x in seq(1,100,1)){

#Step 1 - Re-shuffle the response
#Reshuffle stoich data and place in new file
QtyNStoich_Shuf <- Qty_wB
#We are shuffling the 15th column as this is the Qty N column
QtyNStoich_Shuf[,15] <-sample(QtyNStoich_Shuf[,15])

#Step 2
#Run the model
#Need to do glm because boot works on glm. Normal distribution so same as lm.
wB_QtyN_Rand <- glm(log(Qty_N) ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=QtyNStoich_Shuf)

#Step 3
#Run cross validation
cv <-cv.glm(data=QtyNStoich_Shuf, glmfit=wB_QtyN_Rand, K=10)

#Step 4
#Collect the cv values for each model. For each iteration x save the cv.
QtyN_LM_Output <- rbind(QtyN_LM_Output, data.frame(Iteration = x, CV = cv$delta[2]))

print (x)
}

#Step 5
#Sort random set to calculate 90% CI for cv$delta[2]
QtyN_LM_Output_Sort <- QtyN_LM_Output[order(QtyN_LM_Output$CV),]

###############
#Qty P per plot
#Put results of null Total N LMs here
QtyP_LM_Output <- NULL

#Do it 100 times
for(x in seq(1,100,1)){

#Step 1 - Re-shuffle the response
#Reshuffle stoich data and place in new file
QtyPStoich_Shuf <- Qty_wB
#We are shuffling the 16th column as this is the Qty P column
QtyPStoich_Shuf[,16] <-sample(QtyPStoich_Shuf[,16])

#Step 2
#Run the model
#Need to do glm because boot works on glm. Normal distribution so same as lm.
wB_QtyP_Rand <- glm(log(Qty_P) ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=QtyPStoich_Shuf)

#Step 3
#Run cross validation
cv <-cv.glm(data=QtyPStoich_Shuf, glmfit=wB_QtyP_Rand, K=10)

#Step 4
#Collect the cv values for each model. For each iteration x save the cv.
QtyP_LM_Output <- rbind(QtyP_LM_Output, data.frame(Iteration = x, CV = cv$delta[2]))

print (x)
}

#Step 5
#Sort random set to calculate 90% CI for cv$delta[2]
QtyP_LM_Output_Sort <- QtyP_LM_Output[order(QtyP_LM_Output$CV),]

##################################################################
#Run wB foliar C:N, C:P, and N:P ratio StDMs
#C:N
wB_CNmodel <- glm(CNRatio ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=Qty_wB)
summary(wB_CNmodel)
#make some diagnostic plots of your model to assess fit
par(mfrow=c(2,3))
par(mai=c(0.8,0.85,0.15,0.1))
plot(wB_CNmodel)
hist(resid(wB_CNmodel))

#C:P
wB_CPmodel <- glm(CPRatio ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=Qty_wB)
summary(wB_CPmodel)
#make some diagnostic plots of your model to assess fit
par(mfrow=c(2,3))
par(mai=c(0.8,0.85,0.15,0.1))
plot(wB_CPmodel)
hist(resid(wB_CPmodel))

#N:P
wB_NPmodel <- glm(NPRatio ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=Qty_wB)
summary(wB_NPmodel)
#make some diagnostic plots of your model to assess fit
par(mfrow=c(2,3))
par(mai=c(0.8,0.85,0.15,0.1))
plot(wB_NPmodel)
hist(resid(wB_NPmodel))

########################################################
#k-fold cross validation for ratio models - TRUE models

cv.glm(data=Qty_wB, glmfit=wB_CNmodel, K=10)
cv.glm(data=Qty_wB, glmfit=wB_CPmodel, K=10)
cv.glm(data=Qty_wB, glmfit=wB_NPmodel, K=10)

##################################################################
#Cross-validation error is a relative measure therefore we need to generate random QtyC, QtyN, QtyP models so that we can compare cross validation of the "TRUE" model to the "random" models
#k-fold cross validation for concentration models - random models
#Need to re-shuffle ratio data, fit models, calculate cv.glm

#C:N ratio
#Put results of null Total N LMs here
CN_LM_Output <- NULL

#Do it 100 times
for(x in seq(1,100,1)){

#Step 1 - Re-shuffle the response
#Reshuffle stoich data and place in new file
CNStoich_Shuf <- Qty_wB
#We are shuffling the 20th column as this is the CN column
CNStoich_Shuf[,20] <-sample(CNStoich_Shuf[,20])

#Step 2
#Run the model
#Need to do glm because boot works on glm. Normal distribution so same as lm.
wB_CN_Rand <- glm(CNRatio ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=CNStoich_Shuf)

#Step 3
#Run cross validation
cv <-cv.glm(data=CNStoich_Shuf, glmfit=wB_CN_Rand, K=10)

#Step 4
#Collect the cv values for each model. For each iteration x save the cv.
CN_LM_Output <- rbind(CN_LM_Output, data.frame(Iteration = x, CV = cv$delta[2]))

print (x)
}

#Step 5
#Sort random set to calculate 90% CI for cv$delta[2]
CN_LM_Output_Sort <- CN_LM_Output[order(CN_LM_Output$CV),]

##########
#C:P ratio
#Put results of null Total N LMs here
CP_LM_Output <- NULL

#Do it 100 times
for(x in seq(1,100,1)){

#Step 1 - Re-shuffle the response
#Reshuffle stoich data and place in new file
CPStoich_Shuf <- Qty_wB
#We are shuffling the 21st column as this is the CP column
CPStoich_Shuf[,21] <-sample(CPStoich_Shuf[,21])

#Step 2
#Run the model
#Need to do glm because boot works on glm. Normal distribution so same as lm.
wB_CP_Rand <- glm(CPRatio ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=CPStoich_Shuf)

#Step 3
#Run cross validation
cv <-cv.glm(data=CPStoich_Shuf, glmfit=wB_CP_Rand, K=10)

#Step 4
#Collect the cv values for each model. For each iteration x save the cv.
CP_LM_Output <- rbind(CP_LM_Output, data.frame(Iteration = x, CV = cv$delta[2]))

print (x)
}

#Step 5
#Sort random set to calculate 90% CI for cv$delta[2]
CP_LM_Output_Sort <- CP_LM_Output[order(CP_LM_Output$CV),]

#########
#N:P ratio
#Put results of null Total N LMs here
NP_LM_Output <- NULL

#Do it 100 times
for(x in seq(1,100,1)){

#Step 1 - Re-shuffle the response
#Reshuffle stoich data and place in new file
NPStoich_Shuf <- Qty_wB
#We are shuffling the 22nd column as this is the NP column
NPStoich_Shuf[,22] <-sample(NPStoich_Shuf[,22])

#Step 2
#Run the model
#Need to do glm because boot works on glm. Normal distribution so same as lm.
wB_NP_Rand <- glm(NPRatio ~ SpCode + Height + LandCover + scale(Elevation) + scale(Slope) + scale(AspectNormalized), data=NPStoich_Shuf)

#Step 3
#Run cross validation
cv <-cv.glm(data=NPStoich_Shuf, glmfit=wB_NP_Rand, K=10)

#Step 4
#Collect the cv values for each model. For each iteration x save the cv.
NP_LM_Output <- rbind(NP_LM_Output, data.frame(Iteration = x, CV = cv$delta[2]))

print (x)
}

#Step 5
#Sort random set to calculate 90% CI for cv$delta[2]
NP_LM_Output_Sort <- NP_LM_Output[order(NP_LM_Output$CV),]

########################################################################
#Code to make some figures in ms
########################################################################
#Makes Fig. 2 a % C vs % N
plot(Qty_wB$PercentC, Qty_wB$PercentN, ylab="% Nitrogen", xlab="% Carbon", cex.lab=1.5, cex.axis=1.5, pch=21, col="black", cex=1.5) 

########################################################################
#Code to fit Moose distribution models
########################################################################
#Import data for each moose
#Start with presence (i.e., GPS collar) data
#Plum Point
M002_2013_P <- read.csv("M002_2013_P.csv")
M003_2011_P <- read.csv("M003_2011_P.csv")
M004_2011_P <- read.csv("M004_2011_P.csv")
M005_2011_P <- read.csv("M005_2011_P.csv")
M008_2011_P <- read.csv("M008_2011_P.csv")
M009_2011_P <- read.csv("M009_2011_P.csv")
M006_2015_P <- read.csv("M006_2015_P.csv")

#Old Man's
M004_2014_P <- read.csv("M004_2014_P.csv")
M005_2015_P <- read.csv("M005_2015_P.csv")
M007_2014_P <- read.csv("M007_2014_P.csv")
M011_2014_P <- read.csv("M011_2014_P.csv")
M012_2014_P <- read.csv("M012_2014_P.csv")
M013_2015_P <- read.csv("M013_2015_P.csv")
M015_2014_P <- read.csv("M015_2014_P.csv")

#Top Sails
M007_2010_P <- read.csv("M007_2010_P.csv")
M001_2011_P <- read.csv("M001_2011_P.csv")
M003_2015_P <- read.csv("M003_2015_P.csv")

#Import moose random/available data
#Plum Point
M002_2013_R <- read.csv("M002_2013_R.csv")
M003_2011_R <- read.csv("M003_2011_R.csv")
M004_2011_R <- read.csv("M004_2011_R.csv")
M005_2011_R <- read.csv("M005_2011_R.csv")
M008_2011_R <- read.csv("M008_2011_R.csv")
M009_2011_R <- read.csv("M009_2011_R.csv")
M006_2015_R <- read.csv("M006_2015_R.csv")

#Old Man's
M004_2014_R <- read.csv("M004_2014_R.csv")
M005_2015_R <- read.csv("M005_2015_R.csv")
M007_2014_R <- read.csv("M007_2014_R.csv")
M011_2014_R <- read.csv("M011_2014_R.csv")
M012_2014_R <- read.csv("M012_2014_R.csv")
M013_2015_R <- read.csv("M013_2015_R.csv")
M015_2014_R <- read.csv("M015_2014_R.csv")

#Top Sails
M007_2010_R <- read.csv("M007_2010_R.csv")
M001_2011_R <- read.csv("M001_2011_R.csv")
M003_2015_R <- read.csv("M003_2015_R.csv")

####################################################################################################
#Fit mixed model with moose id as a random effect
#Then compare to models with random moose id to see if adding moose id as random effect improves model
####################################################################################################

#Procedure to select random set of available points to fit 1:1 model design. Number of points will vary based on the number of presence points for each animal. Run model for 1 data set to test mixed model formulation.
#Plum Point
M002_2013_R_Set <- NULL
M003_2011_R_Set <- NULL
M004_2011_R_Set <- NULL
M005_2011_R_Set <- NULL
M008_2011_R_Set <- NULL
M009_2011_R_Set <- NULL
M006_2015_R_Set <- NULL

#Old Man's
M004_2014_R_Set <- NULL
M005_2015_R_Set <- NULL
M007_2014_R_Set <- NULL
M011_2014_R_Set <- NULL
M012_2014_R_Set <- NULL
M013_2015_R_Set <- NULL
M015_2014_R_Set <- NULL

#Top Sails
M007_2010_R_Set <- NULL
M001_2011_R_Set <- NULL
M003_2015_R_Set <- NULL

#Randomly take X rows from the data set without replacement, where X is equal to the number of presence points for that moose.
#Plum Point
M002_2013_R_Set <- M002_2013_R[sample(nrow(M002_2013_R),178),]
M003_2011_R_Set <- M003_2011_R[sample(nrow(M003_2011_R),311),]
M004_2011_R_Set <- M004_2011_R[sample(nrow(M004_2011_R),228),]
M005_2011_R_Set <- M005_2011_R[sample(nrow(M005_2011_R),118),]
M008_2011_R_Set <- M008_2011_R[sample(nrow(M008_2011_R),71),]
M009_2011_R_Set <- M009_2011_R[sample(nrow(M009_2011_R),240),]
M006_2015_R_Set <- M006_2015_R[sample(nrow(M006_2015_R),214),]

#Old Man's
M004_2014_R_Set <- M004_2014_R[sample(nrow(M004_2014_R),284),]
M005_2015_R_Set <- M005_2015_R[sample(nrow(M005_2015_R),254),]
M007_2014_R_Set <- M007_2014_R[sample(nrow(M007_2014_R),261),]
M011_2014_R_Set <- M011_2014_R[sample(nrow(M011_2014_R),270),]
M012_2014_R_Set <- M012_2014_R[sample(nrow(M012_2014_R),241),]
M013_2015_R_Set <- M013_2015_R[sample(nrow(M013_2015_R),364),]
M015_2014_R_Set <- M015_2014_R[sample(nrow(M015_2014_R),152),]

#Top Sails
M007_2010_R_Set <- M007_2010_R[sample(nrow(M007_2010_R),112),]
M001_2011_R_Set <- M001_2011_R[sample(nrow(M001_2011_R),307),]
M003_2015_R_Set <- M003_2015_R[sample(nrow(M003_2015_R),301),]

#Combine with presence and available data for each moose individual
#Plum Point
M002_2013 <- rbind(M002_2013_R_Set,M002_2013_P)
M003_2011 <- rbind(M003_2011_R_Set,M003_2011_P)
M004_2011 <- rbind(M004_2011_R_Set,M004_2011_P)
M005_2011 <- rbind(M005_2011_R_Set,M005_2011_P)
M008_2011 <- rbind(M008_2011_R_Set,M008_2011_P)
M009_2011 <- rbind(M009_2011_R_Set,M009_2011_P)
M006_2015 <- rbind(M006_2015_R_Set,M006_2015_P)

#Old Man's
M004_2014 <- rbind(M004_2014_R_Set,M004_2014_P)
M005_2015 <- rbind(M005_2015_R_Set,M005_2015_P)
M007_2014 <- rbind(M007_2014_R_Set,M007_2014_P)
M011_2014 <- rbind(M011_2014_R_Set,M011_2014_P)
M012_2014 <- rbind(M012_2014_R_Set,M012_2014_P)
M013_2015 <- rbind(M013_2015_R_Set,M013_2015_P)
M015_2014 <- rbind(M015_2014_R_Set,M015_2014_P)

#Top Sails
M007_2010 <- rbind(M007_2010_R_Set,M007_2010_P)
M001_2011 <- rbind(M001_2011_R_Set,M001_2011_P)
M003_2015 <- rbind(M003_2015_R_Set,M003_2015_P)

################################################################################################
#Run variance inflation factor on continuous covariates in 10 sets of models.
#One model without any wB stoich covariate and 8 different models (less %C model) with different wB stoich as covariate
#landscape variables
Scale_Elevation <- MixedData[,7:7]
Scale_Slope <- MixedData[,8:8]
Scale_AspectN <- MixedData[,9:9]
Dist_road <- MixedData[,4:4]
Dist_water <- MixedData[,6:6]
Dist_wetland <- MixedData[,5:5]
PercentN <- MixedData[,11:11]
PercentP <- MixedData[,12:12]
QtyC <- MixedData[,13:13]
QtyN <- MixedData[,14:14]
QtyP <- MixedData[,15:15]
NPratio <- MixedData[,18:18]
CNratio <- MixedData[,16:16]
CPratio <- MixedData[,17:17]

StoichModelVar <- NULL
StoichModelVar <- rbind(StoichModelVar, data.frame(Scale_Elevation=Scale_Elevation, Scale_Slope=Scale_Slope, Scale_AspectN=Scale_AspectN))
MooseModelVar <- NULL
MooseModelVar <- rbind(MooseModelVar, data.frame(Dist_road=scale(Dist_road), Dist_water=scale(Dist_water), Dist_wetland=scale(Dist_wetland)))


#variables for model 1
model1_var <- cbind(StoichModelVar, MooseModelVar)
#variables for model 2
model2_var <- cbind(StoichModelVar, MooseModelVar, scale(PercentN))
#variables for model 3
model3_var <- cbind(StoichModelVar, MooseModelVar, scale(PercentP))
#variables for model 4
model4_var <- cbind(StoichModelVar, MooseModelVar, scale(QtyC))
#variables for model 5
model5_var <- cbind(StoichModelVar, MooseModelVar, scale(QtyN))
#variables for model 6
model6_var <- cbind(StoichModelVar, MooseModelVar, scale(QtyP))
#variables for model 7
model7_var <- cbind(StoichModelVar, MooseModelVar, scale(CNratio))
#variables for model 8
model8_var <- cbind(StoichModelVar, MooseModelVar, scale(CPratio))
#variables for model 9
model9_var <- cbind(StoichModelVar, MooseModelVar, scale(NPratio))

#compute VIF for covariates in all 9 models
vif(model1_var)
vif(model2_var)
vif(model3_var)
vif(model4_var)
vif(model5_var)
vif(model6_var)
vif(model7_var)
vif(model8_var)
vif(model9_var)

#####################################

#Combine moose presence and random data to make file for mixed model fitting
MixedData <- rbind(M002_2013,M003_2011,M004_2011,M005_2011,M008_2011,M009_2011,M006_2015,M004_2014,M005_2015,M007_2014,M011_2014,M012_2014,M013_2015,M015_2014,M001_2011,M007_2010,M003_2015)

#Full (all study areas) Mixed model
Moose_Mixed<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=MixedData, control=glmerControl(optCtrl=list(maxfun=100000)))
summary(Moose_Mixed)
r.squaredGLMM(Moose_Mixed)

################################################################
#Fit GLMM - for Full moose model + each wB stoich StDM prediction (see AIC table below)

#Add wB PercentN
MooseRSF_N<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(PercentN) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=MixedData, control=glmerControl(optCtrl=list(maxfun=100000)))
summary(MooseRSF_N)
r.squaredGLMM(MooseRSF_N)

#Add wB PercentP
MooseRSF_P<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(PercentP) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=MixedData, control=glmerControl(optCtrl=list(maxfun=100000)))
summary(MooseRSF_P)
r.squaredGLMM(MooseRSF_P)

#Add wB qtyC
MooseRSF_QC<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(qtyC) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=MixedData, control=glmerControl(optCtrl=list(maxfun=100000)))
summary(MooseRSF_QC)
r.squaredGLMM(MooseRSF_QC)

#Add wB qtyN
MooseRSF_QN<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(qtyN) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=MixedData, control=glmerControl(optCtrl=list(maxfun=100000)))
summary(MooseRSF_QN)
r.squaredGLMM(MooseRSF_QN)

#Add wB qtyP
MooseRSF_QP<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(qtyP) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=MixedData, control=glmerControl(optCtrl=list(maxfun=100000)))
summary(MooseRSF_QP)
r.squaredGLMM(MooseRSF_QP)

#Add wB CNratio
MooseRSF_CN<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(CNratio) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=MixedData, control=glmerControl(optCtrl=list(maxfun=100000)))
summary(MooseRSF_CN)
r.squaredGLMM(MooseRSF_CN)

#Add wB CPratio
MooseRSF_CP<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(CPratio) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=MixedData, control=glmerControl(optCtrl=list(maxfun=100000)))
summary(MooseRSF_CP)
r.squaredGLMM(MooseRSF_CP)

#Add wB NPratio
MooseRSF_NP<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(NPratio) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=MixedData, control=glmerControl(optCtrl=list(maxfun=100000)))
summary(MooseRSF_NP)
r.squaredGLMM(MooseRSF_NP)

#######################################################################################################
#Run a loop where we fit the moose glmms and run AIC table for 100 different sets of available points
#
MooseFull<-NULL
MoosePercentN<-NULL
MoosePercentP<-NULL
MooseQtyC<-NULL
MooseQtyN<-NULL
MooseQtyP<-NULL
MooseCNratio<-NULL
MooseCPratio<-NULL
MooseNPratio<-NULL
MooseIntercept<-NULL

for(i in seq(1,100,1)){

#Step 1: Select random set
#Plum Point
XXM002_2013_R_Set <- NULL
XXM003_2011_R_Set <- NULL
XXM004_2011_R_Set <- NULL
XXM005_2011_R_Set <- NULL
XXM008_2011_R_Set <- NULL
XXM009_2011_R_Set <- NULL
XXM006_2015_R_Set <- NULL

#Old Man's
XXM004_2014_R_Set <- NULL
XXM005_2015_R_Set <- NULL
XXM007_2014_R_Set <- NULL
XXM011_2014_R_Set <- NULL
XXM012_2014_R_Set <- NULL
XXM013_2015_R_Set <- NULL
XXM015_2014_R_Set <- NULL

#Top Sails
XXM007_2010_R_Set <- NULL
XXM001_2011_R_Set <- NULL
XXM003_2015_R_Set <- NULL


#Randomly take X rows from the data set without replacement, where X is equal to the number of presence points for that moose.
#Plum Point
XXM002_2013_R_Set <- M002_2013_R[sample(nrow(M002_2013_R),178),]
XXM003_2011_R_Set <- M003_2011_R[sample(nrow(M003_2011_R),311),]
XXM004_2011_R_Set <- M004_2011_R[sample(nrow(M004_2011_R),228),]
XXM005_2011_R_Set <- M005_2011_R[sample(nrow(M005_2011_R),118),]
XXM008_2011_R_Set <- M008_2011_R[sample(nrow(M008_2011_R),71),]
XXM009_2011_R_Set <- M009_2011_R[sample(nrow(M009_2011_R),240),]
XXM006_2015_R_Set <- M006_2015_R[sample(nrow(M006_2015_R),214),]

#Old Man's
XXM004_2014_R_Set <- M004_2014_R[sample(nrow(M004_2014_R),284),]
XXM005_2015_R_Set <- M005_2015_R[sample(nrow(M005_2015_R),254),]
XXM007_2014_R_Set <- M007_2014_R[sample(nrow(M007_2014_R),261),]
XXM011_2014_R_Set <- M011_2014_R[sample(nrow(M011_2014_R),270),]
XXM012_2014_R_Set <- M012_2014_R[sample(nrow(M012_2014_R),241),]
XXM013_2015_R_Set <- M013_2015_R[sample(nrow(M013_2015_R),364),]
XXM015_2014_R_Set <- M015_2014_R[sample(nrow(M015_2014_R),152),]

#Top Sails
XXM007_2010_R_Set <- M007_2010_R[sample(nrow(M007_2010_R),112),]
XXM001_2011_R_Set <- M001_2011_R[sample(nrow(M001_2011_R),307),]
XXM003_2015_R_Set <- M003_2015_R[sample(nrow(M003_2015_R),301),]


#Combine this set of available points for a model run
AvailSet <- rbind(XXM002_2013_R_Set,XXM003_2011_R_Set,XXM004_2011_R_Set,XXM005_2011_R_Set,XXM008_2011_R_Set,XXM009_2011_R_Set,XXM006_2015_R_Set,XXM004_2014_R_Set,XXM005_2015_R_Set,XXM007_2014_R_Set,XXM011_2014_R_Set,XXM012_2014_R_Set,XXM013_2015_R_Set,XXM015_2014_R_Set,XXM001_2011_R_Set,XXM007_2010_R_Set,XXM003_2015_R_Set)

#Combine set of presence points for analysis
PreSet <-rbind(M002_2013_P,M003_2011_P,M004_2011_P,M005_2011_P,M008_2011_P,M009_2011_P,M006_2015_P,M004_2014_P,M005_2015_P,M007_2014_P,M011_2014_P,M012_2014_P,M013_2015_P,M015_2014_P,M001_2011_P,M007_2010_P,M003_2015_P)

#Step 2: Combine the data
#Combine with presence data to make file for model fitting
PresAvailSet <- rbind(AvailSet,PreSet)

#Step 3: Fit the models
#AIC table for glm models
#Did not include moose model with wB PercentC covariate as wB PercentC StDM did not validate well.
Cand.models <- list( )
Cand.models[[1]] <- glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
Cand.models[[2]] <- glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(PercentN) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
Cand.models[[3]] <- glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(PercentP) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
Cand.models[[4]] <- glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(qtyC) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
Cand.models[[5]] <- glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(qtyN) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
Cand.models[[6]] <- glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(qtyP) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
Cand.models[[7]] <- glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(CNratio) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
Cand.models[[8]] <- glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(CPratio) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
Cand.models[[9]] <- glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(NPratio) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
Cand.models[[10]] <- glmer(PresAvail~ (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))

##create a vector of names to trace back models in set
Modnames <- c("Full", "PercN","PercP", "qtyC", "qtyN", "qtyP", "CNratio", "CPratio", "NPratio", "intercept")

##generate AICc table
AICTable <- aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE, digits = 4, LL = TRUE)

#Run models here to get r.squared
MooseRSF_Full<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
MooseRSF_Full_R2 <- r.squaredGLMM(MooseRSF_Full)
#Add wB PercentN
MooseRSF_N<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(PercentN) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
MooseRSF_N_R2 <- r.squaredGLMM(MooseRSF_N)
#Add wB PercentP
MooseRSF_P<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(PercentP) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
MooseRSF_P_R2 <- r.squaredGLMM(MooseRSF_P)
#Add wB QtyC
MooseRSF_QC<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(qtyC) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
MooseRSF_QC_R2 <- r.squaredGLMM(MooseRSF_QC)
#Add wB QtyN
MooseRSF_QN<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(qtyN) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
MooseRSF_QN_R2 <- r.squaredGLMM(MooseRSF_QN)
#Add wB QtyP
MooseRSF_QP<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(qtyP) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
MooseRSF_QP_R2 <- r.squaredGLMM(MooseRSF_QP)
#Add wB CNratio
MooseRSF_CN<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(CNratio) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
MooseRSF_CN_R2 <- r.squaredGLMM(MooseRSF_CN)
#Add wB CPratio
MooseRSF_CP<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(CPratio) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
MooseRSF_CP_R2 <- r.squaredGLMM(MooseRSF_CP)
#Add wB NPratio
MooseRSF_NP<-glmer(PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(NPratio) + (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
MooseRSF_NP_R2 <- r.squaredGLMM(MooseRSF_NP)
#Add wB Intercept
MooseRSF_int<-glmer(PresAvail~ (1|MooseID) + (1|StudyArea), family=binomial(link="logit"), data=PresAvailSet, control=glmerControl(optCtrl=list(maxfun=100000)))
MooseRSF_int_R2 <- r.squaredGLMM(MooseRSF_int)

#Step 4: Collect the data in a table for each model
MooseFull <- rbind(MooseFull, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="Full"], LogLik=AICTable$LL[AICTable$Modnames=="Full"], MargR2=MooseRSF_Full_R2[1:1], CondR2=MooseRSF_Full_R2[2:2]))
MoosePercentN <- rbind(MoosePercentN, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="PercN"], LogLik=AICTable$LL[AICTable$Modnames=="PercN"], MargR2=MooseRSF_N_R2[1:1], CondR2=MooseRSF_N_R2[2:2]))
MoosePercentP <- rbind(MoosePercentP, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="PercP"], LogLik=AICTable$LL[AICTable$Modnames=="PercP"], MargR2=MooseRSF_P_R2[1:1], CondR2=MooseRSF_P_R2[2:2]))
MooseQtyC <- rbind(MooseQtyC, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="qtyC"], LogLik=AICTable$LL[AICTable$Modnames=="qtyC"], MargR2=MooseRSF_QC_R2[1:1], CondR2=MooseRSF_QC_R2[2:2]))
MooseQtyN <- rbind(MooseQtyN, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="qtyN"], LogLik=AICTable$LL[AICTable$Modnames=="qtyN"], MargR2=MooseRSF_QN_R2[1:1], CondR2=MooseRSF_QN_R2[2:2]))
MooseQtyP <- rbind(MooseQtyP, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="qtyP"], LogLik=AICTable$LL[AICTable$Modnames=="qtyP"], MargR2=MooseRSF_QP_R2[1:1], CondR2=MooseRSF_QP_R2[2:2]))
MooseCNratio <- rbind(MooseCNratio, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="CNratio"], LogLik=AICTable$LL[AICTable$Modnames=="CNratio"], MargR2=MooseRSF_CN_R2[1:1], CondR2=MooseRSF_CN_R2[2:2]))
MooseCPratio <- rbind(MooseCPratio, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="CPratio"], LogLik=AICTable$LL[AICTable$Modnames=="CPratio"], MargR2=MooseRSF_CP_R2[1:1], CondR2=MooseRSF_CP_R2[2:2]))
MooseNPratio <- rbind(MooseNPratio, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="NPratio"], LogLik=AICTable$LL[AICTable$Modnames=="NPratio"], MargR2=MooseRSF_NP_R2[1:1], CondR2=MooseRSF_NP_R2[2:2]))
MooseIntercept <- rbind(MooseIntercept, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="intercept"], LogLik=AICTable$LL[AICTable$Modnames=="intercept"], MargR2=MooseRSF_int_R2[1:1], CondR2=MooseRSF_int_R2[2:2]))

print(i)
}

#Process simulation data. I want to know the number of times each models is top model, so deltaAICc = 0.00000000 and number of times the model is AIC < 2 of top model. 
#AIC summary results
Summary <- NULL
Summary <- rbind(Summary, data.frame(Rank=c("top","<2", "MeanMargTop", "MeanCondTop"), Full=c(sum(MooseFull$Delta_AICc==0.00000000),sum(MooseFull$Delta_AICc<2.0),mean(MooseFull$MargR2[MooseFull$Delta_AICc==0.00000000]), mean(MooseFull$CondR2[MooseFull$Delta_AICc==0.00000000])), PercentN=c(sum(MoosePercentN$Delta_AICc==0.00000000),sum(MoosePercentN$Delta_AICc<2.0),mean(MoosePercentN$MargR2[MoosePercentN$Delta_AICc==0.00000000]), mean(MoosePercentN$CondR2[MoosePercentN$Delta_AICc==0.00000000])), PercentP=c(sum(MoosePercentP$Delta_AICc==0.00000000),sum(MoosePercentP$Delta_AICc<2.0),mean(MoosePercentP$MargR2[MoosePercentP$Delta_AICc==0.00000000]), mean(MoosePercentP$CondR2[MoosePercentP$Delta_AICc==0.00000000])), QtyC=c(sum(MooseQtyC$Delta_AICc==0.00000000),sum(MooseQtyC$Delta_AICc<2.0),mean(MooseQtyC$MargR2[MooseQtyC$Delta_AICc==0.00000000]), mean(MooseQtyC$CondR2[MooseQtyC$Delta_AICc==0.00000000])), QtyN=c(sum(MooseQtyN$Delta_AICc==0.00000000),sum(MooseQtyN$Delta_AICc<2.0),mean(MooseQtyN$MargR2[MooseQtyN$Delta_AICc==0.00000000]), mean(MooseQtyN$CondR2[MooseQtyN$Delta_AICc==0.00000000])), QtyP=c(sum(MooseQtyP$Delta_AICc==0.00000000),sum(MooseQtyP$Delta_AICc<2.0),mean(MooseQtyP$MargR2[MooseQtyP$Delta_AICc==0.00000000]), mean(MooseQtyP$CondR2[MooseQtyP$Delta_AICc==0.00000000])), CNratio=c(sum(MooseCNratio$Delta_AICc==0.00000000),sum(MooseCNratio$Delta_AICc<2.0),mean(MooseCNratio$MargR2[MooseCNratio$Delta_AICc==0.00000000]), mean(MooseCNratio$CondR2[MooseCNratio$Delta_AICc==0.00000000])), CPratio=c(sum(MooseCPratio$Delta_AICc==0.00000000),sum(MooseCPratio$Delta_AICc<2.0),mean(MooseCPratio$MargR2[MooseCPratio$Delta_AICc==0.00000000]), mean(MooseCPratio$CondR2[MooseCPratio$Delta_AICc==0.00000000])), NPratio=c(sum(MooseNPratio$Delta_AICc==0.00000000),sum(MooseNPratio$Delta_AICc<2.0),mean(MooseNPratio$MargR2[MooseNPratio$Delta_AICc==0.00000000]), mean(MooseNPratio$CondR2[MooseNPratio$Delta_AICc==0.00000000])), Intercept=c(sum(MooseIntercept$Delta_AICc==0.00000000),sum(MooseIntercept$Delta_AICc<2.0),mean(MooseIntercept$MargR2[MooseIntercept$Delta_AICc==0.00000000]), mean(MooseIntercept$CondR2[MooseIntercept$Delta_AICc==0.00000000]))))
Summary

##################################################
#Use Roberts et al. in press Ecography cross validation code to check model performance of top ranked moose model (Full + Qty C)

## Moose model Full + QtyC

#Put results of null GLMMs here
Output <- NULL

#Do it 100 times
for(x in seq(1,100,1)){

#Combine all presence data
Presence <-rbind(M002_2013_P,M003_2011_P,M004_2011_P,M005_2011_P,M008_2011_P,M009_2011_P,M006_2015_P,M004_2014_P,M005_2015_P,M007_2014_P,M011_2014_P,M012_2014_P,M013_2015_P,M015_2014_P,M001_2011_P,M007_2010_P,M003_2015_P)
#Combine all available data
#But first draw random set from full set
#Plum Point
XM002_2013_R_Set <- NULL
XM003_2011_R_Set <- NULL
XM004_2011_R_Set <- NULL
XM005_2011_R_Set <- NULL
XM008_2011_R_Set <- NULL
XM009_2011_R_Set <- NULL
XM006_2015_R_Set <- NULL

#Old Man's
XM004_2014_R_Set <- NULL
XM005_2015_R_Set <- NULL
XM007_2014_R_Set <- NULL
XM011_2014_R_Set <- NULL
XM012_2014_R_Set <- NULL
XM013_2015_R_Set <- NULL
XM015_2014_R_Set <- NULL

#Top Sails
XM007_2010_R_Set <- NULL
XM001_2011_R_Set <- NULL
XM003_2015_R_Set <- NULL


#Randomly take X rows from the data set without replacement, where X is equal to the number of presence points for that moose.
#Plum Point
XM002_2013_R_Set <- M002_2013_R[sample(nrow(M002_2013_R),178),]
XM003_2011_R_Set <- M003_2011_R[sample(nrow(M003_2011_R),311),]
XM004_2011_R_Set <- M004_2011_R[sample(nrow(M004_2011_R),228),]
XM005_2011_R_Set <- M005_2011_R[sample(nrow(M005_2011_R),118),]
XM008_2011_R_Set <- M008_2011_R[sample(nrow(M008_2011_R),71),]
XM009_2011_R_Set <- M009_2011_R[sample(nrow(M009_2011_R),240),]
XM006_2015_R_Set <- M006_2015_R[sample(nrow(M006_2015_R),214),]

#Old Man's
XM004_2014_R_Set <- M004_2014_R[sample(nrow(M004_2014_R),284),]
XM005_2015_R_Set <- M005_2015_R[sample(nrow(M005_2015_R),254),]
XM007_2014_R_Set <- M007_2014_R[sample(nrow(M007_2014_R),261),]
XM011_2014_R_Set <- M011_2014_R[sample(nrow(M011_2014_R),270),]
XM012_2014_R_Set <- M012_2014_R[sample(nrow(M012_2014_R),241),]
XM013_2015_R_Set <- M013_2015_R[sample(nrow(M013_2015_R),364),]
XM015_2014_R_Set <- M015_2014_R[sample(nrow(M015_2014_R),152),]

#Top Sails
XM007_2010_R_Set <- M007_2010_R[sample(nrow(M007_2010_R),112),]
XM001_2011_R_Set <- M001_2011_R[sample(nrow(M001_2011_R),307),]
XM003_2015_R_Set <- M003_2015_R[sample(nrow(M003_2015_R),301),]


#Combine this set of available points for a model run
Available <- rbind(XM002_2013_R_Set,XM003_2011_R_Set,XM004_2011_R_Set,XM005_2011_R_Set,XM008_2011_R_Set,XM009_2011_R_Set,XM006_2015_R_Set,XM004_2014_R_Set,XM005_2015_R_Set,XM007_2014_R_Set,XM011_2014_R_Set,XM012_2014_R_Set,XM013_2015_R_Set,XM015_2014_R_Set,XM001_2011_R_Set,XM007_2010_R_Set,XM003_2015_R_Set)

#Combine presence with random data
MixedData <- rbind(Presence, Available)

##
## 5-fold cross-validation with data split by randomly assigning all GPS fixes from a single individual to a given fold, resulting in 3 folds with 3 individuals each and 2 folds with 4 individuals each. Home ranges of individuals assigned to different folds may overlap. 
# Remove columns used for evaluations fit earlier
MixedData$rand.vec <- NULL   

# split individuals randomly
newdata <- data.frame(MooseID = unique(MixedData$MooseID))

random_sample <- data.frame(MooseID = sample(newdata$MooseID, 17))
random_sample$rand.vec <- 0
random_sample$rand.vec[1:3] <- 1
random_sample$rand.vec[4:6] <- 2
random_sample$rand.vec[7:9] <- 3
random_sample$rand.vec[10:13] <- 4
random_sample$rand.vec[14:17] <- 5
with(random_sample, tapply(MooseID, rand.vec, length))
MixedData <- merge(MixedData, random_sample, by = "MooseID", all.x = T )
with(MixedData, tapply(MooseID, rand.vec, unique))


#####################################################################################
# Define top moose model formula 
formula4 <- PresAvail~ Sp_Code + Height + LandCover + scale_Elevation + scale_Slope + scale_AspectN + scale(dist_road) + scale(dist_water) + scale(dist_wetland) + scale(qtyC) + (1|MooseID) + (1|StudyArea) 


#################################  SLOW STEP  ##################################
model4 <- glmer(formula4, MixedData, family=binomial, control=glmerControl(optCtrl=list(maxfun=100000)))
save(model4, file = "model4.RData")
#load("model4.RData")


################
## Model evaluation sensu Boyce et al. 2002 - Individual block cross-validation
## -------------------------------------------------------------------------------------
##

# Fit the model in all folds but one.
#################################  SLOW STEP  ##################################
mod_inter_randomf16 <- glmer(formula4, MixedData[MixedData$rand.vec != 1,], family = binomial)
mod_inter_randomf17 <- glmer(formula4, MixedData[MixedData$rand.vec != 2,], family = binomial)
mod_inter_randomf18 <- glmer(formula4, MixedData[MixedData$rand.vec != 3,], family = binomial)
mod_inter_randomf19 <- glmer(formula4, MixedData[MixedData$rand.vec != 4,], family = binomial)
mod_inter_randomf20 <- glmer(formula4, MixedData[MixedData$rand.vec != 5,], family = binomial)
save(mod_inter_randomf16, file = "mod_inter_randomf16.RData")
save(mod_inter_randomf17, file = "mod_inter_randomf17.RData")
save(mod_inter_randomf18, file = "mod_inter_randomf18.RData")
save(mod_inter_randomf19, file = "mod_inter_randomf19.RData")
save(mod_inter_randomf20, file = "mod_inter_randomf20.RData")
# load(file = "mod_inter_randomf16.RData")
# load(file = "mod_inter_randomf17.RData")
# load(file = "mod_inter_randomf18.RData")
# load(file = "mod_inter_randomf19.RData")
# load(file = "mod_inter_randomf20.RData")


# Calculation of the contribution to RSF scores by the levels of the categorical predictors (Sp_code, reference category: bF; LandCover, reference category: coniferous; Height, reference category: AA) and calculation of RSF scores assuming the exponential form. Repeating it for each withhold fold. Leave out reference categories


#attach(MixedData)
MixedData$Sp_Code_contribute[MixedData$rand.vec == 1] <- as.numeric(ifelse(MixedData$Sp_Code[MixedData$rand.vec == 1] == "bF", 0,
																ifelse(MixedData$Sp_Code[MixedData$rand.vec == 1] == "bFPlus", mod_inter_randomf16@beta[2],
                                                                   ifelse(MixedData$Sp_Code[MixedData$rand.vec == 1] == "SPlus", mod_inter_randomf16@beta[3],"ERROR"))))
MixedData$Height_contribute[MixedData$rand.vec == 1] <- as.numeric(ifelse(MixedData$Height[MixedData$rand.vec == 1] == "AA", 0,
																ifelse(MixedData$Height[MixedData$rand.vec == 1] == "C", mod_inter_randomf16@beta[4],
                                                                   ifelse(MixedData$Height[MixedData$rand.vec == 1] == "D", mod_inter_randomf16@beta[5],
                                                                       ifelse(MixedData$Height[MixedData$rand.vec == 1] == "Z", mod_inter_randomf16@beta[6],"ERROR")))))                                                                   
MixedData$LandCover_contribute[MixedData$rand.vec == 1] <- as.numeric(ifelse(MixedData$LandCover[MixedData$rand.vec == 1] == "coniferous", 0, 
																ifelse(MixedData$LandCover[MixedData$rand.vec == 1] == "other", mod_inter_randomf16@beta[7],"ERROR")))                                                                   
MixedData$RSFscores[MixedData$rand.vec == 1] = exp(MixedData$Sp_Code_contribute[MixedData$rand.vec == 1] +
										MixedData$Height_contribute[MixedData$rand.vec == 1] +
										MixedData$LandCover_contribute[MixedData$rand.vec == 1] +
										mod_inter_randomf16@beta[8] * MixedData$scale_Elevation[MixedData$rand.vec == 1] +
                                         mod_inter_randomf16@beta[9] * MixedData$scale_Slope[MixedData$rand.vec == 1] +
                                         mod_inter_randomf16@beta[10] * MixedData$scale_AspectN[MixedData$rand.vec == 1] +
                                         mod_inter_randomf16@beta[11] * scale(MixedData$dist_road[MixedData$rand.vec == 1]) +
                                         mod_inter_randomf16@beta[12] * scale(MixedData$dist_water[MixedData$rand.vec == 1]) +
                                         mod_inter_randomf16@beta[13] * scale(MixedData$dist_wetland[MixedData$rand.vec == 1]) +
                                         mod_inter_randomf16@beta[14] * scale(MixedData$qtyC[MixedData$rand.vec == 1]))

MixedData$Sp_Code_contribute[MixedData$rand.vec == 2] <- as.numeric(ifelse(MixedData$Sp_Code[MixedData$rand.vec == 2] == "bF", 0,
                                                            ifelse(MixedData$Sp_Code[MixedData$rand.vec == 2] == "bFPlus", mod_inter_randomf17@beta[2],
                                                                   ifelse(MixedData$Sp_Code[MixedData$rand.vec == 2] == "SPlus", mod_inter_randomf17@beta[3],"ERROR"))))
MixedData$Height_contribute[MixedData$rand.vec == 2] <- as.numeric(ifelse(MixedData$Height[MixedData$rand.vec == 2] == "AA", 0,
                                                            ifelse(MixedData$Height[MixedData$rand.vec == 2] == "C", mod_inter_randomf17@beta[4],
                                                                   ifelse(MixedData$Height[MixedData$rand.vec == 2] == "D", mod_inter_randomf17@beta[5],
                                                                       ifelse(MixedData$Height[MixedData$rand.vec == 2] == "Z", mod_inter_randomf17@beta[6],"ERROR")))))                                                                   
MixedData$LandCover_contribute[MixedData$rand.vec == 2] <- as.numeric(ifelse(MixedData$LandCover[MixedData$rand.vec == 2] == "coniferous", 0,
                                                            ifelse(MixedData$LandCover[MixedData$rand.vec == 2] == "other", mod_inter_randomf17@beta[7],"ERROR")))                                                                   
MixedData$RSFscores[MixedData$rand.vec == 2] = exp(MixedData$Sp_Code_contribute[MixedData$rand.vec == 2] +
										MixedData$Height_contribute[MixedData$rand.vec == 2] +
										MixedData$LandCover_contribute[MixedData$rand.vec == 2] +
										mod_inter_randomf17@beta[8] * MixedData$scale_Elevation[MixedData$rand.vec == 2] +
                                         mod_inter_randomf17@beta[9] * MixedData$scale_Slope[MixedData$rand.vec == 2] +
                                         mod_inter_randomf17@beta[10] * MixedData$scale_AspectN[MixedData$rand.vec == 2] +
                                         mod_inter_randomf17@beta[11] * scale(MixedData$dist_road[MixedData$rand.vec == 2]) +
                                         mod_inter_randomf17@beta[12] * scale(MixedData$dist_water[MixedData$rand.vec == 2]) +
                                         mod_inter_randomf17@beta[13] * scale(MixedData$dist_wetland[MixedData$rand.vec == 2]) +
                                         mod_inter_randomf17@beta[14] * scale(MixedData$qtyC[MixedData$rand.vec == 2]))
                                         
                                         
MixedData$Sp_Code_contribute[MixedData$rand.vec == 3] <- as.numeric(ifelse(MixedData$Sp_Code[MixedData$rand.vec == 3] == "bF", 0,
                                                            ifelse(MixedData$Sp_Code[MixedData$rand.vec == 3] == "bFPlus", mod_inter_randomf18@beta[2],
                                                                   ifelse(MixedData$Sp_Code[MixedData$rand.vec == 3] == "SPlus", mod_inter_randomf18@beta[3],"ERROR"))))
MixedData$Height_contribute[MixedData$rand.vec == 3] <- as.numeric(ifelse(MixedData$Height[MixedData$rand.vec == 3] == "AA", 0,
                                                            ifelse(MixedData$Height[MixedData$rand.vec == 3] == "C", mod_inter_randomf18@beta[4],
                                                                   ifelse(MixedData$Height[MixedData$rand.vec == 3] == "D", mod_inter_randomf18@beta[5],
                                                                       ifelse(MixedData$Height[MixedData$rand.vec == 3] == "Z", mod_inter_randomf18@beta[6],"ERROR")))))                                                                   
MixedData$LandCover_contribute[MixedData$rand.vec == 3] <- as.numeric(ifelse(MixedData$LandCover[MixedData$rand.vec == 3] == "coniferous", 0,
                                                            ifelse(MixedData$LandCover[MixedData$rand.vec == 3] == "other", mod_inter_randomf18@beta[7],"ERROR")))                                                                   
MixedData$RSFscores[MixedData$rand.vec == 3] = exp(MixedData$Sp_Code_contribute[MixedData$rand.vec == 3] +
										MixedData$Height_contribute[MixedData$rand.vec == 3] +
										MixedData$LandCover_contribute[MixedData$rand.vec == 3] +
										mod_inter_randomf18@beta[8] * MixedData$scale_Elevation[MixedData$rand.vec == 3] +
                                         mod_inter_randomf18@beta[9] * MixedData$scale_Slope[MixedData$rand.vec == 3] +
                                         mod_inter_randomf18@beta[10] * MixedData$scale_AspectN[MixedData$rand.vec == 3] +
                                         mod_inter_randomf18@beta[11] * scale(MixedData$dist_road[MixedData$rand.vec == 3]) +
                                         mod_inter_randomf18@beta[12] * scale(MixedData$dist_water[MixedData$rand.vec == 3]) +
                                         mod_inter_randomf18@beta[13] * scale(MixedData$dist_wetland[MixedData$rand.vec == 3]) +
                                         mod_inter_randomf18@beta[14] * scale(MixedData$qtyC[MixedData$rand.vec == 3]))

MixedData$Sp_Code_contribute[MixedData$rand.vec == 4] <- as.numeric(ifelse(MixedData$Sp_Code[MixedData$rand.vec == 4] == "bF", 0,
                                                            ifelse(MixedData$Sp_Code[MixedData$rand.vec == 4] == "bFPlus", mod_inter_randomf19@beta[2],
                                                                   ifelse(MixedData$Sp_Code[MixedData$rand.vec == 4] == "SPlus", mod_inter_randomf19@beta[3],"ERROR"))))
MixedData$Height_contribute[MixedData$rand.vec == 4] <- as.numeric(ifelse(MixedData$Height[MixedData$rand.vec == 4] == "AA", 0,
                                                            ifelse(MixedData$Height[MixedData$rand.vec == 4] == "C", mod_inter_randomf19@beta[4],
                                                                   ifelse(MixedData$Height[MixedData$rand.vec == 4] == "D", mod_inter_randomf19@beta[5],
                                                                       ifelse(MixedData$Height[MixedData$rand.vec == 4] == "Z", mod_inter_randomf19@beta[6],"ERROR")))))                                                                   
MixedData$LandCover_contribute[MixedData$rand.vec == 4] <- as.numeric(ifelse(MixedData$LandCover[MixedData$rand.vec == 4] == "coniferous", 0,
                                                            ifelse(MixedData$LandCover[MixedData$rand.vec == 4] == "other", mod_inter_randomf19@beta[7],"ERROR")))                                                                   
MixedData$RSFscores[MixedData$rand.vec == 4] = exp(MixedData$Sp_Code_contribute[MixedData$rand.vec == 4] +
										MixedData$Height_contribute[MixedData$rand.vec == 4] +
										MixedData$LandCover_contribute[MixedData$rand.vec == 4] +
										mod_inter_randomf19@beta[8] * MixedData$scale_Elevation[MixedData$rand.vec == 4] +
                                         mod_inter_randomf19@beta[9] * MixedData$scale_Slope[MixedData$rand.vec == 4] +
                                         mod_inter_randomf19@beta[10] * MixedData$scale_AspectN[MixedData$rand.vec == 4] +
                                         mod_inter_randomf19@beta[11] * scale(MixedData$dist_road[MixedData$rand.vec == 4]) +
                                         mod_inter_randomf19@beta[12] * scale(MixedData$dist_water[MixedData$rand.vec == 4]) +
                                         mod_inter_randomf19@beta[13] * scale(MixedData$dist_wetland[MixedData$rand.vec == 4]) +
                                         mod_inter_randomf19@beta[14] * scale(MixedData$qtyC[MixedData$rand.vec == 4]))

MixedData$Sp_Code_contribute[MixedData$rand.vec == 5] <- as.numeric(ifelse(MixedData$Sp_Code[MixedData$rand.vec == 5] == "bF", 0,
                                                            ifelse(MixedData$Sp_Code[MixedData$rand.vec == 5] == "bFPlus", mod_inter_randomf20@beta[2],
                                                                   ifelse(MixedData$Sp_Code[MixedData$rand.vec == 5] == "SPlus", mod_inter_randomf20@beta[3],"ERROR"))))
MixedData$Height_contribute[MixedData$rand.vec == 5] <- as.numeric(ifelse(MixedData$Height[MixedData$rand.vec == 5] == "AA", 0,
                                                            ifelse(MixedData$Height[MixedData$rand.vec == 5] == "C", mod_inter_randomf20@beta[4],
                                                                   ifelse(MixedData$Height[MixedData$rand.vec == 5] == "D", mod_inter_randomf20@beta[5],
                                                                       ifelse(MixedData$Height[MixedData$rand.vec == 5] == "Z", mod_inter_randomf20@beta[6],"ERROR")))))                                                                   
MixedData$LandCover_contribute[MixedData$rand.vec == 5] <- as.numeric(ifelse(MixedData$LandCover[MixedData$rand.vec == 5] == "coniferous", 0,
                                                            ifelse(MixedData$LandCover[MixedData$rand.vec == 5] == "other", mod_inter_randomf20@beta[7],"ERROR")))                                                                   
MixedData$RSFscores[MixedData$rand.vec == 5] = exp(MixedData$Sp_Code_contribute[MixedData$rand.vec == 5] +
										MixedData$Height_contribute[MixedData$rand.vec == 5] +
										MixedData$LandCover_contribute[MixedData$rand.vec == 5] +
										mod_inter_randomf20@beta[8] * MixedData$scale_Elevation[MixedData$rand.vec == 5] +
                                         mod_inter_randomf20@beta[9] * MixedData$scale_Slope[MixedData$rand.vec == 5] +
                                         mod_inter_randomf20@beta[10] * MixedData$scale_AspectN[MixedData$rand.vec == 5] +
                                         mod_inter_randomf20@beta[11] * scale(MixedData$dist_road[MixedData$rand.vec == 5]) +
                                         mod_inter_randomf20@beta[12] * scale(MixedData$dist_water[MixedData$rand.vec == 5]) +
                                         mod_inter_randomf20@beta[13] * scale(MixedData$dist_wetland[MixedData$rand.vec == 5]) +
                                         mod_inter_randomf20@beta[14] * scale(MixedData$qtyC[MixedData$rand.vec == 5]))

# Run the k-fold CV evaluation sensu Boyce et al. 2002
dataset <- MixedData[complete.cases(MixedData[,"RSFscores"]),]
rho_model <- numeric(5) ## it will store Spearman's coefficients

fold <- subset(dataset,rand.vec==unique(dataset$rand.vec)[1]) # run the procedure for the 1st fold - the for-loop below will work on folds 2 to 5
q.pp <- quantile(fold$RSFscores,probs=seq(0,1,.1)) ## computing quantiles of RSF scores
# --------------------------------------------------------
bin <- rep(NA,length(fold$RSFscores))
for (j in 1:10){
  bin[fold$RSFscores>=q.pp[j]& fold$RSFscores<q.pp[j+1]] = j ## binning RSF scores (10 bins)
}
used <- fold$PresAvail
# --------------------------------------------------------
a <- table(used,bin) ## Occurrence of presence and available data by bin
a <- t(a) #transpose the table
a <- as.data.frame.matrix(a) ## the next few lines compute area-adjusted frequency of categories (bins) of RSF scores 
a$areaadjusted <- rep(NA,length(10))
sum0 <- sum(a[,1])
sum1 <- sum(a[,2])
a$areaadjusted <- (a[,2] / sum1 ) / (a[,1] / sum0)
a$bins <- seq(1,10,by=1);a

# --------------------------------------------------------
rho_model[1] <- with(a,cor.test(bins,areaadjusted,method="spearm"))$estimate ## Spearman correlation coefficient between RSF bin ranks and area-adjusted frequencies
# --------------------------------------------------------


for (i in 2:5){
  fold <- subset(dataset,rand.vec==unique(dataset$rand.vec)[i]) ## run the procedure on folds 2 to 5
  # --------------------------------------------------------
  q.pp <- quantile(fold$RSFscores,probs=seq(0,1,.1)) ## computing quantiles of RSF scores
  # --------------------------------------------------------
  bin <- rep(NA,length(fold$RSFscores))
  for (j in 1:10){
    bin[fold$RSFscores>=q.pp[j]& fold$RSFscores<q.pp[j+1]] = j  ## binning RSF scores (10 bins)
  }
  used <- fold$PresAvail
  # --------------------------------------------------------
  a <- table(used,bin) ## area adjusted freq in used/available for each bin
  a <- t(a) #transpose the table
  a <- as.data.frame.matrix(a) ## the next few lines compute area-adjusted frequency of categories (bins) of RSF scores 
  a$areaadjusted <- rep(NA,length(10))
  sum0 <- sum(a[,1])
  sum1 <- sum(a[,2])
  a$areaadjusted <- (a[,2] / sum1 ) / (a[,1] / sum0)
  a$bins <- seq(1,10,by=1);a
  # --------------------------------------------------------
  rho_model[i] <- with(a,cor.test(bins,areaadjusted,method="spearm"))$estimate ## store Spearman correlation coefficients between RSF bin ranks and area-adjusted frequencies
  # --------------------------------------------------------
  
}
#dev.off()

## store Spearman correlation coefficients that will be used for final plots below ##
Rho_random_individuals4 <- rho_model

print (x)
}
##############################
#Make Figure 3 from the ms with full landscape N:PRatio, All moose N:PRatio and one moose N:PRatio
#Import Five moose we use N:PRatio data from GIS
LandscapeNP <- read.csv("7MooseNPRatio.csv")

#Make density of N:P in full landscape
Dens_LandscapeNP <- density(LandscapeNP$GRID_CODE)

#Combine Old Man's moose data into one file
Presence <- rbind(M004_2014_P, M005_2015_P, M007_2014_P, M011_2014_P, M012_2014_P, M013_2015_P, M015_2014_P)

#Make density of N:P for all moose
Dens_AllMoose <- density(Presence$NPratio)

#Make density of N:P for individual moose
Dens_M012 <- density(M012_2014_P$NPratio)

#Now plot it
plot(Dens_LandscapeNP, xlab="white birch N:P ratio", ylab ="frequency", col="black", xlim=c(15, 31), ylim=c(0,0.35), lwd=2, main="", cex.axis=1.5, cex.lab=1.5)
lines(Dens_AllMoose, lwd=2 ,lty="dashed")
lines(Dens_M012, lty="dotted", lwd=2)
#Let's add a legend to the above plot
legend("topright", legend=c("Landscape", "All moose", "Moose M012"), lty=c("solid", "dashed", "dotted"), pt.cex=1.5, lwd=1.5)






